@@ -111,8 +111,8 @@ int  xine_check_version (int major, int minor, int sub) XINE_PROTECTED;
 /* static info - which libxine release this header came from */
 #define XINE_MAJOR_VERSION 1
 #define XINE_MINOR_VERSION 1
-#define XINE_SUB_VERSION   17
-#define XINE_VERSION       "1.1.17"
+#define XINE_SUB_VERSION   21
+#define XINE_VERSION       "1.1.21"
 
 /*
  * pre-init the xine engine
@@ -132,6 +132,12 @@ int  xine_check_version (int major, int minor, int sub) XINE_PROTECTED;
  */
 xine_t *xine_new (void) XINE_PROTECTED;
 
+/* allow the setting of some flags before xine_init
+ * FIXME-ABI: this is currently GLOBAL
+ */
+void xine_set_flags (xine_t *, int) XINE_PROTECTED __attribute__((weak));
+#define XINE_FLAG_NO_WRITE_CACHE		1
+
 /*
  * post_init the xine engine
  */
@@ -367,6 +373,7 @@ int  xine_get_param (xine_stream_t *stream, int param) XINE_PROTECTED;
 #define XINE_PARAM_VO_SATURATION           0x01000003 /* 0..65535           */
 #define XINE_PARAM_VO_CONTRAST             0x01000004 /* 0..65535           */
 #define XINE_PARAM_VO_BRIGHTNESS           0x01000005 /* 0..65535           */
+#define XINE_PARAM_VO_GAMMA                0x0100000c /* 0..65535           */
 #define XINE_PARAM_VO_ZOOM_X               0x01000008 /* percent            */
 #define XINE_PARAM_VO_ZOOM_Y               0x0100000d /* percent            */
 #define XINE_PARAM_VO_PAN_SCAN             0x01000009 /* bool               */
@@ -983,7 +990,7 @@ const char *xine_get_meta_info   (xine_stream_t *stream, int info) XINE_PROTECTE
 #define XINE_META_INFO_ARTIST              2
 #define XINE_META_INFO_GENRE               3
 #define XINE_META_INFO_ALBUM               4
-#define XINE_META_INFO_YEAR                5
+#define XINE_META_INFO_YEAR                5 /* may be full date */
 #define XINE_META_INFO_VIDEOCODEC          6
 #define XINE_META_INFO_AUDIOCODEC          7
 #define XINE_META_INFO_SYSTEMLAYER         8
@@ -991,6 +998,22 @@ const char *xine_get_meta_info   (xine_stream_t *stream, int info) XINE_PROTECTE
 #define XINE_META_INFO_CDINDEX_DISCID      10
 #define XINE_META_INFO_TRACK_NUMBER        11
 #define XINE_META_INFO_COMPOSER            12
+/* post-1.1.17; taken from the list at http://age.hobba.nl/audio/mirroredpages/ogg-tagging.html on 2009-12-11 */
+#define XINE_META_INFO_PUBLISHER	   13
+#define XINE_META_INFO_COPYRIGHT	   14
+#define XINE_META_INFO_LICENSE		   15
+#define XINE_META_INFO_ARRANGER		   16
+#define XINE_META_INFO_LYRICIST		   17
+#define XINE_META_INFO_AUTHOR		   18
+#define XINE_META_INFO_CONDUCTOR	   19
+#define XINE_META_INFO_PERFORMER	   20
+#define XINE_META_INFO_ENSEMBLE		   21
+#define XINE_META_INFO_OPUS		   22
+#define XINE_META_INFO_PART		   23
+#define XINE_META_INFO_PARTNUMBER	   24
+#define XINE_META_INFO_LOCATION		   25
+/* post-1.1.18.1 */
+#define XINE_META_INFO_DISCNUMBER	   26
 
 
 /*********************************************************************
@@ -1701,6 +1724,7 @@ void xine_config_reset (xine_t *self) XINE_PROTECTED;
 #define XINE_EVENT_DROPPED_FRAMES        12 /* number of dropped frames is too high */
 #define XINE_EVENT_MRL_REFERENCE_EXT     13 /* demuxer->frontend: MRL reference(s) for the real stream */
 #define XINE_EVENT_AUDIO_AMP_LEVEL       14 /* report current audio amp level (l/r/mute) */
+#define XINE_EVENT_NBC_STATS             15 /* nbc buffer status */
 
 
 /* input events coming from frontend */
@@ -1780,6 +1804,7 @@ void xine_config_reset (xine_t *self) XINE_PROTECTED;
 #define XINE_EVENT_VDR_INFO             333
 #define XINE_EVENT_VDR_CHANNELPREVIOUS  334
 #define XINE_EVENT_VDR_SUBTITLES        335
+#define XINE_EVENT_VDR_USER0            336
 /* some space for further keys */
 #define XINE_EVENT_VDR_SETVIDEOWINDOW   350
 #define XINE_EVENT_VDR_FRAMESIZECHANGED 351
@@ -1884,6 +1909,23 @@ typedef struct {
   int                 percent;
 } xine_progress_data_t;
 
+/*
+ * nbc buffer status
+ */
+typedef struct {
+  int                 v_percent;    /* fill of video buffer */
+  int64_t             v_remaining;  /* remaining time in ms till underrun */
+  int64_t             v_bitrate;    /* current bitrate */
+  int                 v_in_disc;    /* in discontinuity */
+  int                 a_percent;    /* like video, but for audio */
+  int64_t             a_remaining;
+  int64_t             a_bitrate;
+  int                 a_in_disc;
+  int                 buffering;    /* currently filling buffer */
+  int                 enabled;      /* buffer disabled by engine */
+  int                 type;         /* 0=buffer put, 1=buffer get */
+} xine_nbc_stats_data_t;
+
 /*
  * mrl reference data is sent by demuxers when a reference stream is found.
  * this stream just contains pointers (urls) to the real data, which are
